@@ -1,9 +1,9 @@
 package Log::ger::Util;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-10'; # DATE
+our $DATE = '2020-03-11'; # DATE
 our $DIST = 'Log-ger'; # DIST
-our $VERSION = '0.036'; # VERSION
+our $VERSION = '0.037'; # VERSION
 
 use strict;
 use warnings;
@@ -229,10 +229,19 @@ sub set_plugin {
         require $mod_pm;
         my $meta  = $mod->can("meta") ? $mod->meta : {v=>1};
         my $v     = $meta->{v} || 1;
-        unless ($v == 1) {
-            die "Plugin '$mod' follows meta version $v but Log::ger ".
+
+        # history of v bumping:
+        #
+        # - v increased from 1 to 2 in Log::ger v0.037 to force all plugins that
+        #   were not compatible with Log::ger 0.032 (removed
+        #   create_logml_routine phase) to be upgraded.
+
+        unless ($v == 2) {
+            die "Plugin '$mod' (version ".(${"$mod\::VERSION"} || "dev").")".
+                " follows meta version $v but Log::ger (version ".
                 (${__PACKAGE__."::VERSION"} || "dev").
-                " requires meta version 1, please upgrade the plugin";
+                ") (>0.032) requires meta version 2, ".
+                "please upgrade the plugin first";
         }
         $hooks = &{"$mod\::get_hooks"}(%{ $args{conf} || {} });
     }
@@ -297,7 +306,7 @@ Log::ger::Util - Utility routines for Log::ger
 
 =head1 VERSION
 
-version 0.036
+version 0.037
 
 =head1 DESCRIPTION
 
